@@ -23,7 +23,7 @@
 
 #include <iostream>
 #include <fstream>
-#include <stdlib.h>
+#include <cstdlib>
 
 #include "fileutil.h"
 #include "verbosity.h"
