@@ -7,10 +7,12 @@
 #include <iomanip>
 
 #include "linenumgenerator.h"
-#include "my_sstream.h"
+#include <sstream>
 
 using namespace std;
 
+namespace srchilite {
+
 /// used for line information generation
 static SubstitutionMapping substitutionmapping;
 
@@ -40,3 +42,5 @@ const std::string LineNumGenerator::generateLine(unsigned int line) {
 
     return line_str + " ";
 }
+
+}
