@@ -257,6 +257,9 @@ void SourceHighlight::highlight(const std::string &input,
         noDocGenerator->setTitle(input);
     }
 
+    docGenerator->setInputLang(inputLang);
+    noDocGenerator->setInputLang(inputLang);      
+
     if (ctagsFormatter) {
         // if we need to generate references, then set the file info
         ctagsFormatter->setFileInfo(input, output);
@@ -334,6 +337,8 @@ void SourceHighlight::highlight(std::istream &input, std::ostream &output,
         documentGenerator->setTitle(title);
     }
 
+    documentGenerator->setInputLang(inputLang);
+
     // first generate the start of the output file
     documentGenerator->generate_start_doc(&output);
 
