@@ -24,10 +24,11 @@ import java.io.* ;
  * A simple Hello World class, used to demonstrate some
  * features of Java source highlighting.
  * </p>
+ * TODO: nothing, just to show an highlighted TODO or FIXME
  *
  * @author Lorenzo Bettini
  * @version 2.0
- */
+ */ /// class
 public class Hello {
     int foo = 1998 ;
     int hex_foo = 0xCAFEBABE;
@@ -35,7 +36,14 @@ public class Hello {
     Integer i = null ;
     char c = '\'', d = 'n', e = '\\' ;
     String xml = "<tag attr=\"value\">&auml;</tag>", foo2 = "\\" ;
-    
+
+    /* mymethod */
+    public void mymethod(int i) {
+	// just a foo method
+    }
+    /* mymethod */
+   
+    /* main */
     public static void main( String args[] ) {
 	// just some greetings ;-)  /*
 	System.out.println( "Hello from java2html :-)" ) ;
@@ -45,4 +53,8 @@ public class Hello {
             String param = argc[0];
         //System.out.println( "bye bye... :-D" ) ; // see you soon
     }
+    /* main */
 }
+/// class
+
+// end of file test.java
\ No newline at end of file
